==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/cfjeui.f <==
      SUBROUTINE CFJEUI(NDIM,
     &                  JAPCOE,JAPDDL,JAPJEU,JAPMEM,JAPPAR,
     &                  JAPPTR,JDDL,JNORMO,JNRINI,JPDDL,JTANGO,
     &                  TANGDF,
     &                  MULNOR,CMULT,
     &                  POSNOE,IESCL,REACTU)
C
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 07/10/2004   AUTEUR MABBAS M.ABBAS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C
      IMPLICIT     NONE
      INTEGER      NDIM
      INTEGER      JAPCOE
      INTEGER      JAPDDL
      INTEGER      JAPJEU
      INTEGER      JAPMEM
      INTEGER      JAPPAR
      INTEGER      JAPPTR
      INTEGER      JDDL
      INTEGER      JNORMO
      INTEGER      JNRINI
      INTEGER      JPDDL 
      INTEGER      JTANGO
      LOGICAL      MULNOR
      REAL*8       CMULT
      INTEGER      TANGDF
      INTEGER      POSNOE
      INTEGER      IESCL
      INTEGER      REACTU
C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : RECHPA
C ----------------------------------------------------------------------
C
C REMPLISSAGE INITIAL DANS RESOCO POUR L'APPARIEMENT
C
C IN  NDIM   : DIMENSION DE L'ESPACE (2 OU 3)
C IN  JAPCOE : POINTEUR VERS RESOCO(1:14)//'.APCOEF'
C IN  JAPDDL : POINTEUR VERS RESOCO(1:14)//'.APDDL'
C IN  JAPJEU : POINTEUR VERS RESOCO(1:14)//'.APJEU'
C IN  JAPMEM : POINTEUR VERS RESOCO(1:14)//'.APMEMO'
C IN  JAPPAR : POINTEUR VERS RESOCO(1:14)//'.APPARI'
C IN  JAPPTR : POINTEUR VERS RESOCO(1:14)//'.APPOIN'
C IN  JDDL   : POINTEUR VERS DEFICO(1:16)//'.DDLCO'
C IN  JNORMO : POINTEUR VERS RESOCO(1:14)//'.NORMCO'
C IN  JNRINI : POINTEUR VERS RESOCO(1:14)//'.NORINI'
C IN  JPDDL  : POINTEUR VERS DEFICO(1:16)//'.PDDLCO'
C IN  JTANGO : POINTEUR VERS RESOCO(1:14)//'.TANGCO'
C IN  TANGDF : INDICATEUR DE PRESENCE D'UN VECT_Y DEFINI PAR 
C              L'UTILISATEUR
C               0 PAS DE VECT_Y
C               1 UN VECT_Y EST DEFINI
C IN  MULNOR : LOGIQUE QUI VAUT 1 LORSQU'ON MULTIPLIE LES COEFFICIENTS
C              DE LA RELATION UNILATERALE PAR LES COMPOSANTES DES
C              NORMALES
C IN  CMULT  : COEFFICIENT DE LA RELATION UNILATERALE (ISSU DU
C              MOT-CLE COEF_MULT_2 OU 1)
C IN  POSNOE : POSITION DANS DEFICO(1:16)//'.CONTNO' DU NOEUD ESCLAVE
C IN  IESCL  : INDICE DU NOEUD ESCLAVE
C IN  REACTU : INDICATEUR DE REACTUALISATION POUR TOUTE LA ZONE
C              DES NORMALES ET DU JEU
C
C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C
C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER      ZAPPAR
      PARAMETER    (ZAPPAR=3)
      INTEGER      ZAPMEM
      PARAMETER    (ZAPMEM=4)
      INTEGER      JDECAL,JDECDL,K
      INTEGER      NBDDLE,NBDDLM
      REAL*8       XNORM(3),XTANG(6),NORME
C
C ----------------------------------------------------------------------

      CALL JEMARQ()
C --- POSITION DE LA MAILLE MAITRE APPARIEE : POS=0
      ZI(JAPPAR+ZAPPAR* (IESCL-1)+1)  = POSNOE
      ZI(JAPPAR+ZAPPAR* (IESCL-1)+2)  = 0
      ZI(JAPPAR+ZAPPAR* (IESCL-1)+3)  = REACTU

      ZI(JAPMEM+ZAPMEM* (POSNOE-1))   = 1
      ZI(JAPMEM+ZAPMEM* (POSNOE-1)+1) = 0
      ZI(JAPMEM+ZAPMEM* (POSNOE-1)+2) = 0
      ZI(JAPMEM+ZAPMEM* (POSNOE-1)+3) = 0
C
      NBDDLE = ZI(JPDDL+POSNOE) - ZI(JPDDL+POSNOE-1)
      NBDDLM = 0
C
      IF ((NBDDLE.GT.3) .OR. (NBDDLM.GT.3)) THEN
        CALL UTMESS('F','CFJEUI','ON NE PEUT PAS AVOIR PLUS'//
     &                  ' DE 3 DDLS IMPLIQUES DANS LA MEME RELATION'//
     &                  ' UNILATERALE')
      END IF

      ZI(JAPPAR+ZAPPAR* (IESCL-1)+3) = 0
C
C --- VECTEUR NORMAL ET VECTEURS TANGENTS
C

      XNORM(1) = ZR(JNRINI+3* (POSNOE-1)  )
      XNORM(2) = ZR(JNRINI+3* (POSNOE-1)+1)
      XNORM(3) = ZR(JNRINI+3* (POSNOE-1)+2)

      CALL NORMEV(XNORM,NORME)
      CALL CFTANG(NDIM,XNORM,XTANG,TANGDF)
      CALL R8COPY(3,XNORM,1,ZR(JNORMO+3* (IESCL-1)),1)
      CALL R8COPY(6,XTANG,1,ZR(JTANGO+6* (IESCL-1)),1)

      ZR(JAPJEU+IESCL-1) = 0.D0

      JDECAL = ZI(JAPPTR+IESCL-1)
      JDECDL = ZI(JPDDL+POSNOE-1)

      DO 30 K = 1,NBDDLE
        ZR(JAPCOE+JDECAL+K-1) = 1.D0*CMULT
        IF (MULNOR) THEN
          ZR(JAPCOE+JDECAL+K-1) = ZR(JAPCOE+JDECAL+K-1)*
     &                            ZR(JNORMO+3*(IESCL-1)+K-1)
        END IF
        ZI(JAPDDL+JDECAL+K-1) = ZI(JDDL+JDECDL+K-1)
   30 CONTINUE

      ZI(JAPPTR+IESCL) = ZI(JAPPTR+IESCL-1) + NBDDLE + NBDDLM

C ----------------------------------------------------------------------

      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/cfjeui.f <==
      SUBROUTINE CFJEUI(NDIM,
     &                  JAPCOE,JAPDDL,JAPJEU,JAPMEM,JAPPAR,
     &                  JAPPTR,JDDL,JNORMO,JNRINI,JPDDL,JTANGO,
     &                  TANGDF,
     &                  MULNOR,CMULT,
     &                  POSNOE,IESCL,REACTU)
C
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 16/12/2004   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C
      IMPLICIT     NONE
      INTEGER      NDIM
      INTEGER      JAPCOE
      INTEGER      JAPDDL
      INTEGER      JAPJEU
      INTEGER      JAPMEM
      INTEGER      JAPPAR
      INTEGER      JAPPTR
      INTEGER      JDDL
      INTEGER      JNORMO
      INTEGER      JNRINI
      INTEGER      JPDDL 
      INTEGER      JTANGO
      LOGICAL      MULNOR
      REAL*8       CMULT
      INTEGER      TANGDF
      INTEGER      POSNOE
      INTEGER      IESCL
      INTEGER      REACTU
C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : RECHPA
C ----------------------------------------------------------------------
C
C REMPLISSAGE INITIAL DANS RESOCO POUR L'APPARIEMENT
C
C IN  NDIM   : DIMENSION DE L'ESPACE (2 OU 3)
C IN  JAPCOE : POINTEUR VERS RESOCO(1:14)//'.APCOEF'
C IN  JAPDDL : POINTEUR VERS RESOCO(1:14)//'.APDDL'
C IN  JAPJEU : POINTEUR VERS RESOCO(1:14)//'.APJEU'
C IN  JAPMEM : POINTEUR VERS RESOCO(1:14)//'.APMEMO'
C IN  JAPPAR : POINTEUR VERS RESOCO(1:14)//'.APPARI'
C IN  JAPPTR : POINTEUR VERS RESOCO(1:14)//'.APPOIN'
C IN  JDDL   : POINTEUR VERS DEFICO(1:16)//'.DDLCO'
C IN  JNORMO : POINTEUR VERS RESOCO(1:14)//'.NORMCO'
C IN  JNRINI : POINTEUR VERS RESOCO(1:14)//'.NORINI'
C IN  JPDDL  : POINTEUR VERS DEFICO(1:16)//'.PDDLCO'
C IN  JTANGO : POINTEUR VERS RESOCO(1:14)//'.TANGCO'
C IN  TANGDF : INDICATEUR DE PRESENCE D'UN VECT_Y DEFINI PAR 
C              L'UTILISATEUR
C               0 PAS DE VECT_Y
C               1 UN VECT_Y EST DEFINI
C IN  MULNOR : LOGIQUE QUI VAUT 1 LORSQU'ON MULTIPLIE LES COEFFICIENTS
C              DE LA RELATION UNILATERALE PAR LES COMPOSANTES DES
C              NORMALES
C IN  CMULT  : COEFFICIENT DE LA RELATION UNILATERALE (ISSU DU
C              MOT-CLE COEF_MULT_2 OU 1)
C IN  POSNOE : POSITION DANS DEFICO(1:16)//'.CONTNO' DU NOEUD ESCLAVE
C IN  IESCL  : INDICE DU NOEUD ESCLAVE
C IN  REACTU : INDICATEUR DE REACTUALISATION POUR TOUTE LA ZONE
C              DES NORMALES ET DU JEU
C
C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C
C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER      ZAPPAR
      PARAMETER    (ZAPPAR=3)
      INTEGER      ZAPMEM
      PARAMETER    (ZAPMEM=4)
      INTEGER      JDECAL,JDECDL,K
      INTEGER      NBDDLE,NBDDLM
      REAL*8       XNORM(3),XTANG(6),NORME
C
C ----------------------------------------------------------------------

      CALL JEMARQ()
C --- POSITION DE LA MAILLE MAITRE APPARIEE : POS=0
      ZI(JAPPAR+ZAPPAR* (IESCL-1)+1)  = POSNOE
      ZI(JAPPAR+ZAPPAR* (IESCL-1)+2)  = 0
      ZI(JAPPAR+ZAPPAR* (IESCL-1)+3)  = REACTU

      ZI(JAPMEM+ZAPMEM* (POSNOE-1))   = 1
      ZI(JAPMEM+ZAPMEM* (POSNOE-1)+1) = 0
      ZI(JAPMEM+ZAPMEM* (POSNOE-1)+2) = 0
      ZI(JAPMEM+ZAPMEM* (POSNOE-1)+3) = 0
C
      NBDDLE = ZI(JPDDL+POSNOE) - ZI(JPDDL+POSNOE-1)
      NBDDLM = 0
C
      IF ((NBDDLE.GT.3) .OR. (NBDDLM.GT.3)) THEN
        CALL UTMESS('F','CFJEUI','ON NE PEUT PAS AVOIR PLUS'//
     &                  ' DE 3 DDLS IMPLIQUES DANS LA MEME RELATION'//
     &                  ' UNILATERALE')
      END IF

      ZI(JAPPAR+ZAPPAR* (IESCL-1)+3) = 0
C
C --- VECTEUR NORMAL ET VECTEURS TANGENTS
C

      XNORM(1) = ZR(JNRINI+3* (POSNOE-1)  )
      XNORM(2) = ZR(JNRINI+3* (POSNOE-1)+1)
      XNORM(3) = ZR(JNRINI+3* (POSNOE-1)+2)

      CALL NORMEV(XNORM,NORME)
      CALL CFTANG(NDIM,XNORM,XTANG,TANGDF)
      CALL DCOPY(3,XNORM,1,ZR(JNORMO+3* (IESCL-1)),1)
      CALL DCOPY(6,XTANG,1,ZR(JTANGO+6* (IESCL-1)),1)

      ZR(JAPJEU+IESCL-1) = 0.D0

      JDECAL = ZI(JAPPTR+IESCL-1)
      JDECDL = ZI(JPDDL+POSNOE-1)

      DO 30 K = 1,NBDDLE
        ZR(JAPCOE+JDECAL+K-1) = 1.D0*CMULT
        IF (MULNOR) THEN
          ZR(JAPCOE+JDECAL+K-1) = ZR(JAPCOE+JDECAL+K-1)*
     &                            ZR(JNORMO+3*(IESCL-1)+K-1)
        END IF
        ZI(JAPDDL+JDECAL+K-1) = ZI(JDDL+JDECDL+K-1)
   30 CONTINUE

      ZI(JAPPTR+IESCL) = ZI(JAPPTR+IESCL-1) + NBDDLE + NBDDLM

C ----------------------------------------------------------------------

      CALL JEDEMA()
      END
